////////////////////////////////////////////////////////////////////////////////
//
// Proyecto Medusa v3.0
//
//////////////////////////////////// INFO //////////////////////////////////////
//
//  Nombre del programa : Medusa.exe
//  Fecha               : Septiembre del 2003.
//  Componentes         : DOA 3.4.6.4, SynEdit 1.1 (CVS).
//  Version compilador  : Delphi 6.0 Enterprise.
//  Descripcin         : Un cliente avanzado de Oracle
//  Autor               : Albert Philippe De La Fuente Vigliotti.
//  Tutor               : Jos Galindo Gmez.
//
////////////////////////////////////////////////////////////////////////////////

unit UComentarios;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, Oracle, Buttons;

type
  TFrmComentarios = class(TForm)
    CmBxTabla: TComboBox;
    CmBxColumna: TComboBox;
    MmoTabla: TMemo;
    Label1: TLabel;
    Label2: TLabel;
    MmoColumna: TMemo;
    OracleQry: TOracleQuery;
    BitBtnOk: TBitBtn;
    BitBtnCancelar: TBitBtn;
    BitBtnAplicarTabla: TBitBtn;
    BitBtnAplicarColumna: TBitBtn;
    procedure FormActivate(Sender: TObject);
    procedure CmBxTablaSelect(Sender: TObject);
    procedure CmBxColumnaSelect(Sender: TObject);
    procedure MmoTablaKeyDown(Sender: TObject; var Key: Word;
      Shift: TShiftState);
    procedure MmoColumnaKeyDown(Sender: TObject; var Key: Word;
      Shift: TShiftState);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure BitBtnAplicarTablaClick(Sender: TObject);
    procedure BitBtnAplicarColumnaClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  FrmComentarios: TFrmComentarios;

implementation

uses UGlobal, UPrincipal, UEditor;

{$R *.dfm}

//TODO: NO Aadido a la memoria

procedure TFrmComentarios.FormActivate(Sender: TObject);
var
  i : Integer;
begin
  try
    CargarEstadoForm(Self);
  except
  end;

  CmBxTabla.Clear;
  CmBxColumna.Clear;
  MmoTabla.Clear;
  MmoColumna.Clear;
  OracleQry.Session := TFrmEditor(FrmPrincipal.ActiveMDIChild).OracleSession;

  // LISTAMOS TODAS LAS TABLAS
  with OracleQry do
  begin
    Close;
    Clear;
    DeleteVariables;
    SQL.Add('SELECT TABLE_NAME');
    SQL.Add('FROM USER_TABLES');
    Execute;
    while not Eof do
    begin
      CmBxTabla.Items.Add(Field('TABLE_NAME'));
      OracleQry.Next;
    end;
  end;
end;

procedure TFrmComentarios.CmBxTablaSelect(Sender: TObject);
begin
  // MOSTRAMOS EL COMENTARIO DE LA TABLA SELECCIONADA
  with OracleQry do
  begin
    MmoTabla.Clear;
    Close;
    Clear;
    DeleteVariables;
    SQL.Add('SELECT COMMENTS');
    SQL.Add('FROM USER_TAB_COMMENTS');
    SQL.Add('WHERE UPPER(TABLE_NAME) = :TABLA');
    DeclareVariable(':TABLA', otString);
    SetVariable(':TABLA', CmBxTabla.Text);
    Execute;
    if not FieldIsNull('COMMENTS') then
      MmoTabla.Lines.Add(Field('COMMENTS'));
  end;

  // LISTAMOS LAS COLUMNAS DE LA TABLA SELECCIONADA
  with OracleQry do
  begin
    CmBxColumna.Clear;
    Close;
    Clear;
    DeleteVariables;
    SQL.Add('SELECT COLUMN_NAME');
    SQL.Add('FROM USER_TAB_COLUMNS');
    SQL.Add('WHERE UPPER(TABLE_NAME) = :TABLA');
    DeclareVariable(':TABLA', otString);
    SetVariable(':TABLA', CmBxTabla.Text);
    Execute;
    while not Eof do
    begin
      CmBxColumna.Items.Add(Field('COLUMN_NAME'));
      OracleQry.Next;
    end;
  end;
end;

procedure TFrmComentarios.CmBxColumnaSelect(Sender: TObject);
var
  Str : String;
begin
  // MOSTRAMOS EL COMENTARIO DE LA TABLA SELECCIONADA
  with OracleQry do
  begin
    MmoColumna.Clear;
    Close;
    Clear;
    DeleteVariables;
    SQL.Add('SELECT COMMENTS');
    SQL.Add('FROM USER_COL_COMMENTS');
    SQL.Add('WHERE (UPPER(TABLE_NAME) = UPPER(:TABLA))');
    SQL.Add('  AND (UPPER(COLUMN_NAME) = UPPER(:COLUMNA))');
    DeclareVariable(':TABLA', otString);
    SetVariable(':TABLA', CmBxTabla.Text);
    DeclareVariable(':COLUMNA', otString);
    SetVariable(':COLUMNA', CmBxColumna.Text);
    Execute;
    if not FieldIsNull('COMMENTS') then
      MmoColumna.Lines.Add(Field('COMMENTS'));
  end;
end;

procedure TFrmComentarios.MmoTablaKeyDown(Sender: TObject; var Key: Word;
  Shift: TShiftState);
begin
  BitBtnAplicarTabla.Enabled := true;
end;

procedure TFrmComentarios.MmoColumnaKeyDown(Sender: TObject; var Key: Word;
  Shift: TShiftState);
begin
  BitBtnAplicarColumna.Enabled := true;
end;

procedure TFrmComentarios.FormClose(Sender: TObject;
  var Action: TCloseAction);
begin
  try
    GuardarEstadoForm(Self);
  except
  end;
end;

procedure TFrmComentarios.BitBtnAplicarTablaClick(Sender: TObject);
begin
  // ACTUALIZAMOS EL COMENTARIO DE LA TABLA SELECCIONADA
  with OracleQry do
  begin
    Close;
    Clear;
    DeleteVariables;
    SQL.Add('COMMENT ON TABLE ' + CmBxTabla.Text + ' IS ''' + MmoTabla.Text + '''');
    Execute;
    BitBtnAplicarTabla.Enabled := false;
  end;
end;

procedure TFrmComentarios.BitBtnAplicarColumnaClick(Sender: TObject);
begin
  // ACTUALIZAMOS EL COMENTARIO DE LA COLUMNA SELECCIONADA
  with OracleQry do
  begin
    Close;
    Clear;
    DeleteVariables;
    SQL.Add('COMMENT ON COLUMN ' + CmBxTabla.Text + '.' + CmBxColumna.Text + ' IS ''' + MmoColumna.Text + '''');
    Execute;
    BitBtnAplicarColumna.Enabled := false;
  end;
end;

end.

// 213
