////////////////////////////////////////////////////////////////////////////////
//
// Proyecto Medusa v3.0
//
//////////////////////////////////// INFO //////////////////////////////////////
//
//  Nombre del programa : Medusa.exe
//  Fecha               : Septiembre del 2003.
//  Componentes         : DOA 3.4.6.4, SynEdit 1.1 (CVS).
//  Version compilador  : Delphi 6.0 Enterprise.
//  Descripcin         : Un cliente avanzado de Oracle
//  Autor               : Albert Philippe De La Fuente Vigliotti.
//  Tutor               : Jos Galindo Gmez.
//
////////////////////////////////////////////////////////////////////////////////
unit UGlobal;

interface

uses Forms, IniFiles, SysUtils, Windows, ShellApi, SynEdit, UDMGlobal,
  UConfiguracion;


const
  FichConfig          = 'Medusa.ini';
  FichMenuDD          = 'MenuDD.mnu';
  FichMenuDDInv       = 'MenuDDInv.mnu';
  FichDCI             = 'Medusa.lac';
  FichLAT             = 'Oracle.lat';
  PathFavoritos       = 'Favoritos';
  SGuardarCambios     = 'Guardar cambios a %s?';
  SSobreEscribir      = 'Sobre-escribir a %s';
  SNuevo              = 'Sin titulo';
  SExt                = 'sql';
  SModificado         = 'Modificado';
  SInfoFilaColumna    = 'L: %3d   C: %3d';
  SInfoLineaWarning   = 'L: %5d -> %s';
  STextoNoEncontrado  = 'Texto no encontrado';
  STokenFich          = '%fich';

  MarcaOffset         = 14;
  MarcaWarning        = 12;


var
  TituloApp : String ;//= 'Medusa v' + GetAppInfo('FileVersion') + ' <Editor sql*plus++>';
  // Esto en realidad, es usado exactamente igual que una constante, pero como
  // tiene una funcin, pues no lo puedo poner en la parte const...

// options - to be saved to the registry
var
  gbBuscarAtras: boolean;
  gbBuscarMayusMinus: boolean;
  gbBuscarDesdeCaret: boolean = true;
  gbSearchSelectionOnly: boolean;
  gbSearchTextAtCaret: boolean;
  gbSearchWholeWords: boolean;

  gsSearchText: string;
  gsSearchTextHistory: string;
  gsReplaceText: string;
  gsReplaceTextHistory: string;



procedure CargarEstadoForm(AForm: TForm);
procedure GuardarEstadoForm(AForm: TForm);
procedure ConfigSynEditDefecto(SynEdit: TSynEdit);
function GetTokenCount(Cadena, Separador: string): integer;
function GetToken(Cadena, Separador:string; Token:integer):string;
function CambiaEn(Cadena, Esto, Por: String): String;
function MatchStrings(source, pattern: String): Boolean;

function  GetAppInfo(Exe, De: string): string;
function CopiaTodo(Origen, Destino: String): LongInt;
procedure BorrarTodo(Dir: String);
function Encrypt(aFrase: String; aClave: Integer): String;
function Decrypt(aFrase: String; aClave: Integer): String;

implementation

// Carga la configuracion de un formulario desde el fichero ini "FichConfig".
// NOTA: Reside donde este el ejecutable.
// Esto deberia ser un procedimiento de clase, con lo cual deberia haber
// herencia pero, me parece que no *reconocera* bien delphi despues los
// formularios del tipo "TMiForm"
procedure CargarEstadoForm(AForm: TForm);
var
  Ini : TIniFile;
begin
  try
    Ini     := TIniFile.Create(ExtractFilePath(ParamStr(0)) + '\' + FichConfig);
    AForm.Top     := Ini.ReadInteger(AForm.Name, 'Top',    AForm.Top);
    AForm.Height  := Ini.ReadInteger(AForm.Name, 'Height', AForm.Height);
    AForm.Left    := Ini.ReadInteger(AForm.Name, 'Left',   AForm.Left);
    AForm.Width   := Ini.ReadInteger(AForm.Name, 'Width',  AForm.Width);
  finally
    Ini.Free;
  end;
end;

// Guarda la configuracion de un formulario en el fichero ini "FichConfig".
// NOTA: Reside donde este el ejecutable.
procedure GuardarEstadoForm(AForm: TForm);
var
  Ini : TIniFile;
begin
  try
    Ini := TIniFile.Create(ExtractFilePath(ParamStr(0)) + '\' + FichConfig);
    Ini.WriteInteger(AForm.Name, 'Top',     AForm.Top);
    Ini.WriteInteger(AForm.Name, 'Height',  AForm.Height);
    Ini.WriteInteger(AForm.Name, 'Left',    AForm.Left);
    Ini.WriteInteger(AForm.Name, 'Width',   AForm.Width);
  finally
    Ini.Free;
  end;
end;

procedure ConfigSynEditDefecto(SynEdit: TSynEdit);
begin
  with SynEdit do
  begin
    Highlighter := DMGlobal.SynSQLSyn;
    if FrmConfiguracion.ChkBxHome.Checked then
      Options               := Options + [eoEnhanceHomeKey]
    else
      Options               := Options - [eoEnhanceHomeKey];

    if FrmConfiguracion.ChkBxTab.Checked then
      Options               := Options + [eoSmartTabs]
    else
      Options               := Options - [eoSmartTabs];
    TabWidth                := FrmConfiguracion.SpnEdtTab.Value;
    WantTabs                := true;    
  end;
end;

function GetTokenCount(Cadena, Separador: String):integer;
var
  Posicion: Integer;
begin
  Posicion := Pos(Separador,Cadena);
  Result   := 1;
  if Cadena <> '' then
  begin
  if Posicion <> 0 then
    while Posicion <> 0 do
    begin
      Delete(Cadena,1,Posicion);
      Posicion:=Pos(Separador,Cadena);
      Inc (Result);
    end;
  end
  else
    Result:=0;
end;


function GetToken(Cadena, Separador: string; Token: integer): string;
//  Cadena     es la string en la que buscar el token
//  Separador  es la string que separa cada token
//  Token      es el nmero de token que buscamos
var
  Posicion  : integer;
begin
  while Token > 1 do begin
    Delete(Cadena, 1, Pos(Separador, Cadena));
    Dec(Token);
  end;
  Posicion := Pos(Separador, Cadena);
  if Posicion=0 then
    result := cadena
  else
    Result := Copy(Cadena, 1, Posicion - Length(Separador));
end;


function CambiaEn(Cadena, Esto, Por: String): String;
var
  aPos: Integer;
begin
  aPos := Pos(Esto, Cadena);
  Result:= '';
  while (aPos <> 0) do begin
    Result := Result + Copy(Cadena, 1, aPos-1) + Por;
    Delete(Cadena, 1, aPos + Length(Esto)-1);
    aPos := Pos(Esto, Cadena);
  end;
  Result := Result+Cadena;
end;

function MatchStrings(source, pattern: String): Boolean;
var
  pSource: array [0..255] of Char;
  pPattern: array [0..255] of Char;
 
  function MatchPattern(element, pattern: PChar): Boolean;

    function IsPatternWild(pattern: PChar): Boolean;
    begin
      Result := StrScan(pattern,'*') <> nil;
      if not Result then
        Result := StrScan(pattern,'?') <> nil;
    end;

  begin
    if 0 = StrComp(pattern,'*') then
      Result := True
    else if (element^ = Chr(0)) and (pattern^ <> Chr(0)) then 
      Result := False
    else if element^ = Chr(0) then
      Result := True
    else begin
      case pattern^ of
        '*':  if MatchPattern(element,@pattern[1]) then
                Result := True
              else
                Result := MatchPattern(@element[1],pattern);
        '?':  Result := MatchPattern(@element[1],@pattern[1]);
        else
          if element^ = pattern^ then
            Result := MatchPattern(@element[1],@pattern[1])
          else
            Result := False;
      end;
    end;
  end;
begin
  StrPCopy(pSource,source);
  StrPCopy(pPattern,pattern);
  Result := MatchPattern(pSource,pPattern);
end;
 



function  GetAppInfo(Exe, De: string): string;
{Se pueden pedir los siguientes datos:
   CompanyName,     FileDescription,    FileVersion,    InternalName
   LegalCopyright,  OriginalFilename,   ProductName,    ProductVersion          }
type
  PaLeerBuffer = array [0..MAX_PATH] of char;

var
  Size, Size2 : DWord;
  Pt, Pt2     : Pointer;
  Idioma      : string;

begin
  Result := '';
  Size := GetFileVersionInfoSize(PChar(Exe), Size2);
  if Size > 0 then
  begin
    GetMem(Pt, Size);
    GetFileVersionInfo(PChar(ParamStr(0)), 0, Size, Pt);
// Obtenemos la cadena de translacion, requerida para obtener el resto de datos del Versioninfo
    VerQueryValue(Pt, '\VarFileInfo\Translation', Pt2, Size2);
    Idioma := IntToHex(DWord(Pt2^), 8);
// Le damos la vuelta (Es windows, que quieres...
    Idioma := Copy(Idioma, 5, 4) + Copy(Idioma, 1, 4);
// Pedimos la info requerida...
    VerQueryValue(Pt, Pchar('\StringFileInfo\' + Idioma + '\' + De), Pt2, Size2);
    if Size2 > 0 then
    begin
// Y la devolvemos
      Result := Copy(PaLeerBuffer(Pt2^), 1, Size2);
    end;
    FreeMem(Pt);
  end;
end;


function CopiaTodo(Origen, Destino: String): LongInt;
var
  F : TShFileOpStruct;
  sOrigen, sDestino : String;
begin
  Result := 0;
  sOrigen := Origen + #0;
  sDestino := Destino + #0;

  with F do
  begin
    Wnd   := Application.Handle;
    wFunc := FO_COPY;
    pFrom := @sOrigen[1];
    pTo   := @sDestino[1];
    fFlags := FOF_ALLOWUNDO or FOF_NOCONFIRMATION
  end;

  Result := ShFileOperation(F);
end;

procedure BorrarTodo(Dir: String);
var
  DirInfo: TSearchRec;
  r : Integer;
begin
  r := FindFirst(Dir + '\*.*', FaAnyfile, DirInfo);
  while r = 0 do
  begin
    if ((DirInfo.Attr and FaDirectory <> FaDirectory) and
        (DirInfo.Attr and FaVolumeId <> FaVolumeID)) then
      DeleteFile(PChar(Dir + '\' + DirInfo.Name))
    else if (DirInfo.Name <> '.') and (DirInfo.Name <> '..') and
            (DirInfo.Attr and FaDirectory = FaDirectory) then
      BorrarTodo(Dir + '\' + DirInfo.Name);
    r := FindNext(DirInfo);
  end;
  SysUtils.FindClose(DirInfo);
  RemoveDir(Dir);
end;

function Encrypt(aFrase: String; aClave: Integer): String;
var
  aa  : Integer;
begin
   Result := '';
   RandSeed := aClave;
   for aa := 1 to Length(aFrase) do
     Result := Result + Chr(Byte(aFrase[aa]) xor random(256));
end;

function Decrypt(aFrase: String; aClave: Integer): String;
var
  aa  : Integer;
begin
  Result := '';
  RandSeed := aClave;
  for aa := 1 to Length(aFrase) do
    Result := Result + Chr(Byte(aFrase[aa]) xor random(256));
end;


end.

// 337
