////////////////////////////////////////////////////////////////////////////////
//
// Proyecto Medusa v3.0
//
//////////////////////////////////// INFO //////////////////////////////////////
//
//  Nombre del programa : Medusa.exe
//  Fecha               : Septiembre del 2003.
//  Componentes         : DOA 3.4.6.4, SynEdit 1.1 (CVS).
//  Version compilador  : Delphi 6.0 Enterprise.
//  Descripcin         : Un cliente avanzado de Oracle
//  Autor               : Albert Philippe De La Fuente Vigliotti.
//  Tutor               : Jos Galindo Gmez.
//
////////////////////////////////////////////////////////////////////////////////

unit UPermisos;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, ExtCtrls, Buttons, Oracle;

type
  TFrmPermisos = class(TForm)
    RdGrpTipoObjeto: TRadioGroup;
    LstBxPermisosDisponibles: TListBox;
    SpdBtnGrant: TSpeedButton;
    SpdBtnRevoke: TSpeedButton;
    CmBxUsuarios: TComboBox;
    Label1: TLabel;
    OracleQuery: TOracleQuery;
    OracleSession: TOracleSession;
    LblObjetos: TLabel;
    CmBxObjetos: TComboBox;
    procedure RdGrpTipoObjetoClick(Sender: TObject);
    procedure FormActivate(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure SpdBtnGrantClick(Sender: TObject);
    procedure LstBxPermisosDisponiblesClick(Sender: TObject);
    procedure SpdBtnRevokeClick(Sender: TObject);
  private
    { Private declarations }
    procedure CargarCampoCmBxObjetos(Str: String);
    procedure CargarCampoCmBxUsuarios(Str: String);
    procedure CargarCampoLstBxPermisosDisponibles(Str: String);
    procedure AgregarRoles;
    procedure AgregarPrivilegios;
    procedure AgregarPrivTablas;
    procedure AgregarPrivVistas;
    procedure AgregarPrivProcedimientos;
    procedure AgregarPrivFunciones;
    procedure AgregarPrivPaquetes;
  public
    { Public declarations }
  end;

var
  FrmPermisos: TFrmPermisos;

implementation

uses UDMGlobal, UPrincipal, UConfiguracion, UGlobal, UEditor;

{$R *.dfm}

procedure TFrmPermisos.CargarCampoCmBxObjetos(Str: String);
begin
  CmBxObjetos.Clear;
  while not OracleQuery.Eof do
  begin
    CmBxObjetos.Items.Add(OracleQuery.Field(Str));
    OracleQuery.Next;
  end;
end;

procedure TFrmPermisos.CargarCampoCmBxUsuarios(Str: String);
begin
  CmBxUsuarios.Clear;
  while not OracleQuery.Eof do
  begin
    CmBxUsuarios.Items.Add(OracleQuery.Field(Str));
    OracleQuery.Next;
  end;
end;

procedure TFrmPermisos.CargarCampoLstBxPermisosDisponibles(Str: String);
begin
  LstBxPermisosDisponibles.Clear;
  while not OracleQuery.Eof do
  begin
    LstBxPermisosDisponibles.Items.Add(OracleQuery.Field(Str));
    OracleQuery.Next;
  end;
end;

procedure TFrmPermisos.AgregarRoles;
begin
  with LstBxPermisosDisponibles.Items do
  begin
    Clear;
    Add('AQ_ADMINISTRATOR_ROLE');
    Add('AQ_USER_ROLE');
    Add('CONNECT');
    Add('DBA');
    Add('DELETE_CATALOG_ROLE');
    Add('EXECUTE_CATALOG_ROLE');
    Add('EXP_FULL_DATABASE');
    Add('IMP_FULL_DATABASE');
    Add('JAVADEBUGPRIV');
    Add('JAVAIDPRIV');
    Add('JAVASYSPRIV');
    Add('JAVAUSERPRIV');
    Add('RECOVERY_CATALOG_OWNER');
    Add('RESOURCE');
    Add('SELECT_CATALOG_ROLE');
    Add('SNMPAGENT');
  end;
end;

procedure TFrmPermisos.AgregarPrivilegios;
begin
  with LstBxPermisosDisponibles.Items do
  begin
    Clear;
    Add('CREATE ANY CLUSTER');
    Add('CREATE ANY CONTEXT');
    Add('CREATE ANY DIMENSION');
    Add('CREATE ANY DIRECTORY');
    Add('CREATE ANY INDEX');
    Add('CREATE ANY INDEXTYPE');
    Add('CREATE ANY LIBRARY');
    Add('CREATE ANY OPERATOR');
    Add('CREATE ANY OUTLINE');
    Add('CREATE ANY PROCEDURE');
    Add('CREATE ANY SEQUENCE');
    Add('CREATE ANY SNAPSHOT');
    Add('CREATE ANY SYNONYM');
    Add('CREATE ANY TABLE');
    Add('CREATE ANY TRIGGER');
    Add('CREATE ANY TYPE');
    Add('CREATE ANY VIEW');
    Add('CREATE CLUSTER');
    Add('CREATE DATABASE LINK');
    Add('CREATE DIMENSION');
    Add('CREATE INDEXTYPE');
    Add('CREATE LIBRARY');
    Add('CREATE OPERATOR');
    Add('CREATE PROCEDURE');
    Add('CREATE PROFILE');
    Add('CREATE PUBLIC DATABASE LINK');
    Add('CREATE PUBLIC SYNONYM');
    Add('CREATE ROLE');
    Add('CREATE ROLLBACK SEGMENT');
    Add('CREATE SEQUENCE');
    Add('CREATE SESSION');
    Add('CREATE SNAPSHOT');
    Add('CREATE SYNONYM');
    Add('CREATE TABLE');
    Add('CREATE TABLESPACE');
    Add('CREATE TRIGGER');
    Add('CREATE TYPE');
    Add('CREATE USER');
    Add('CREATE VIEW');
    Add('ALTER ANY CLUSTER');
    Add('ALTER ANY DIMENSION');
    Add('ALTER ANY INDEX');
    Add('ALTER ANY INDEXTYPE');
    Add('ALTER ANY LIBRARY');
    Add('ALTER ANY OUTLINE');
    Add('ALTER ANY PROCEDURE');
    Add('ALTER ANY ROLE');
    Add('ALTER ANY SEQUENCE');
    Add('ALTER ANY SNAPSHOT');
    Add('ALTER ANY TABLE');
    Add('ALTER ANY TRIGGER');
    Add('ALTER ANY TYPE');
    Add('ALTER DATABASE');
    Add('ALTER PROFILE');
    Add('ALTER RESOURCE COST');
    Add('ALTER ROLLBACK SEGMENT');
    Add('ALTER SESSION');
    Add('ALTER SYSTEM');
    Add('ALTER TABLESPACE');
    Add('ALTER USER');
    Add('DELETE ANY TABLE');
    Add('DROP ANY CLUSTER');
    Add('DROP ANY CONTEXT');
    Add('DROP ANY DIMENSION');
    Add('DROP ANY DIRECTORY');
    Add('DROP ANY INDEX');
    Add('DROP ANY INDEXTYPE');
    Add('DROP ANY LIBRARY');
    Add('DROP ANY OPERATOR');
    Add('DROP ANY OUTLINE');
    Add('DROP ANY PROCEDURE');
    Add('DROP ANY ROLE');
    Add('DROP ANY SEQUENCE');
    Add('DROP ANY SNAPSHOT');
    Add('DROP ANY SYNONYM');
    Add('DROP ANY TABLE');
    Add('DROP ANY TRIGGER');
    Add('DROP ANY TYPE');
    Add('DROP ANY VIEW');
    Add('DROP PROFILE');
    Add('DROP PUBLIC DATABASE LINK');
    Add('DROP PUBLIC SYNONYM');
    Add('DROP ROLLBACK SEGMENT');
    Add('DROP TABLESPACE');
    Add('DROP USER');
    Add('ENQUEUE ANY QUEUE');
    Add('EXECUTE ANY INDEXTYPE');
    Add('EXECUTE ANY LIBRARY');
    Add('EXECUTE ANY OPERATOR');
    Add('EXECUTE ANY PROCEDURE');
    Add('EXECUTE ANY TYPE');
    Add('FORCE ANY TRANSACTION');
    Add('FORCE TRANSACTION');
    Add('GLOBAL QUERY REWRITE');
    Add('GRANT ANY PRIVILEGE');
    Add('GRANT ANY ROLE');
    Add('INSERT ANY TABLE');
    Add('LOCK ANY TABLE');
    Add('MANAGE ANY QUEUE');
    Add('MANAGE TABLESPACE');
    Add('QUERY REWRITE');
    Add('RESTRICTED SESSION');
    Add('SELECT ANY SEQUENCE');
    Add('SELECT ANY TABLE');
    Add('UNLIMITED TABLESPACE');
    Add('UPDATE ANY TABLE');
  end; // with
end;

procedure TFrmPermisos.AgregarPrivTablas;
begin
  with LstBxPermisosDisponibles.Items do
  begin
    Clear;
    Add('ALTER');
    Add('DELETE');
    Add('INDEX');
    Add('INSERT');
    Add('REFERENCES');
    Add('SELECT');
    Add('UPDATE');
  end;
end;

procedure TFrmPermisos.AgregarPrivVistas;
begin
  with LstBxPermisosDisponibles.Items do
  begin
    Clear;
    Add('DELETE');
    Add('INSERT');
    Add('SELECT');
    Add('UPDATE');
  end;
end;

procedure TFrmPermisos.AgregarPrivProcedimientos;
begin
  with LstBxPermisosDisponibles.Items do
  begin
    Clear;
    Add('EXECUTE');
  end;
end;

procedure TFrmPermisos.AgregarPrivFunciones;
begin
  with LstBxPermisosDisponibles.Items do
  begin
    Clear;
    Add('EXECUTE');
  end;
end;

procedure TFrmPermisos.AgregarPrivPaquetes;
begin
  with LstBxPermisosDisponibles.Items do
  begin
    Clear;
    Add('EXECUTE');
  end;
end;

procedure TFrmPermisos.RdGrpTipoObjetoClick(Sender: TObject);
begin
  CmBxObjetos.Enabled := not (RdGrpTipoObjeto.ItemIndex in [0, 1]);
  LblObjetos.Enabled  := not (RdGrpTipoObjeto.ItemIndex in [0, 1]);
  LstBxPermisosDisponibles.MultiSelect := RdGrpTipoObjeto.ItemIndex in [0, 1];
  with OracleQuery, OracleQuery.SQL do
  begin
    Close;
    Clear;
    DeleteVariables;
    
{    if not OracleSession.Connected then
    begin
      DMGlobal.OracleLogon.Session := OracleSession;
      DMGlobal.OracleLogon.Execute;
    end;}


    // CARGAMOS EL COMBO BOX CON LOS USUARIOS (COMN A TODAS LAS OPCIONES)
    Clear;
    Add('SELECT UserName');
    Add('FROM ALL_USERS');
    Execute;
    CargarCampoCmBxUsuarios('UserName');
    Close;

    if RdGrpTipoObjeto.ItemIndex = 0 then // Roles
    begin
      // CARGAMOS EL LISTBOX DE ROLES DISPONIBLES EN LA IZQUIERDA
{      Clear;
      Add('SELECT Role');
      Add('FROM ROLE_SYS_PRIVS');
      Add('GROUP BY Role');
      Execute;
      CargarCampoLstBxPermisosDisponibles('Role');
      Close;}
      AgregarRoles;
    end
    else if RdGrpTipoObjeto.ItemIndex = 1 then  // Privilegios
    begin
      // CARGAMOS EL LISTBOX DE ROLES DISPONIBLES EN LA IZQUIERDA
{      Clear;
      Add('SELECT Privilege');
      Add('FROM ROLE_SYS_PRIVS');
      Add('GROUP BY Privilege');
      Execute;
      CargarCampoLstBxPermisosDisponibles('Privilege');
      Close;}
      AgregarPrivilegios;
    end
    else if RdGrpTipoObjeto.ItemIndex = 2 then  // Tablas
    begin
      // CARGAMOS EL COMBO BOX CON LOS OBJETOS
      Clear;
      Add('SELECT Table_Name');
      Add('FROM ALL_TABLES');
      Execute;
      CargarCampoCmBxObjetos('Table_Name');
      Close;
      AgregarPrivTablas;
    end
    else if RdGrpTipoObjeto.ItemIndex = 3 then  // Vistas
    begin
      // CARGAMOS EL COMBO BOX CON LOS OBJETOS
      Clear;
      Add('SELECT View_Name');
      Add('FROM ALL_VIEWS');
      Execute;
      CargarCampoCmBxObjetos('View_Name');
      Close;
      AgregarPrivVistas;
    end
    else if RdGrpTipoObjeto.ItemIndex = 4 then  // Vistas materializadas
    begin
      // CARGAMOS EL COMBO BOX CON LOS OBJETOS
      Clear;
      Add('SELECT View_Name');
      Add('FROM ALL_VIEWS');
      Execute;
      CargarCampoCmBxObjetos('View_Name');
      Close;
      AgregarPrivVistas;
    end
    else if RdGrpTipoObjeto.ItemIndex = 5 then // Procedimientos
    begin
      // CARGAMOS EL COMBO BOX CON LOS OBJETOS
      Clear;
      Add('SELECT Name');
      Add('FROM ALL_SOURCE');
      Add('WHERE Type = ''PROCEDURE''');
      Add('GROUP BY Name');
      Execute;
      CargarCampoCmBxObjetos('Name');
      Close;
      AgregarPrivProcedimientos;
    end
    else if RdGrpTipoObjeto.ItemIndex = 6 then  // Funciones
    begin
      // CARGAMOS EL COMBO BOX CON LOS OBJETOS
      Clear;
      Add('SELECT Name');
      Add('FROM ALL_SOURCE');
      Add('WHERE Type = ''FUNCTION''');
      Add('GROUP BY Name');
      Execute;
      CargarCampoCmBxObjetos('Name');
      Close;
      AgregarPrivFunciones;
    end
    else if RdGrpTipoObjeto.ItemIndex = 7 then  // Paquetes
    begin
      // CARGAMOS EL COMBO BOX CON LOS OBJETOS
      Clear;
      Add('SELECT Name');
      Add('FROM ALL_SOURCE');
      Add('WHERE Type = ''PACKAGE''');
      Add('GROUP BY Name');
      Execute;
      CargarCampoCmBxObjetos('Name');
      Close;
      AgregarPrivPaquetes;
    end
  end;
end;

procedure TFrmPermisos.FormActivate(Sender: TObject);
begin
  try
    CargarEstadoForm(Self);   // Esto es por si se ejecuta desde CD...
  except
  end;
{  if not OracleSession.Connected then
  begin
    // Limpiamos todos los campos del formulario.
    OracleSession.LogonUsername := '';
    OracleSession.LogonPassword := '';
    OracleSession.LogonDatabase := '';
    RdGrpTipoObjeto.ItemIndex   := -1;
    CmBxUsuarios.Clear;
    LstBxPermisosDisponibles.Clear;
    LstBxPermisosActuales.Clear;
    // Esto no se muy bien porque hay que hacerlo...
    ActiveControl := CmBxObjetos;

    // Y asignamos ventana de conexin a la sesin.
    DMGlobal.OracleLogon.Session := OracleSession;
    DMGlobal.OracleLogon.Execute;
  end;}
  OracleQuery.Session := TFrmEditor(FrmPrincipal.ActiveMDIChild).OracleSession;
end;

procedure TFrmPermisos.FormClose(Sender: TObject;
  var Action: TCloseAction);
begin
  try
    GuardarEstadoForm(Self);
  except
  end;  
  OracleSession.LogOff;
end;

procedure TFrmPermisos.SpdBtnGrantClick(Sender: TObject);
var
  Str, Temp : String;
  i         : Integer;
begin
  with OracleQuery.SQL do
  begin
    OracleQuery.Close;
    OracleQuery.DeleteVariables;
    Clear;

    Temp := '';
    for i := 0 to LstBxPermisosDisponibles.Items.Count -1 do
      if LstBxPermisosDisponibles.Selected[i] then
        Temp := Temp + LstBxPermisosDisponibles.Items[i] + ', ';
    SetLength(Temp, Length(Temp) - 2);

    Str := 'GRANT ' + Temp;
    if CmBxObjetos.Enabled then
      Str := Str + ' ON ' + CmBxObjetos.Items[CmBxObjetos.ItemIndex];

    Str := Str + ' TO ' + CmBxUsuarios.Items[CmBxUsuarios.ItemIndex];
    Add(Str);

    if CmBxUsuarios.Items[CmBxUsuarios.ItemIndex] = '' then
      ShowMessage('Debe seleccionar un usuario')
    else if LstBxPermisosDisponibles.Items[LstBxPermisosDisponibles.ItemIndex] = '' then
      ShowMessage('Debe seleccionar un privilegio')
    else begin
      try
        OracleQuery.Execute;
        ShowMessage('El(los) privilegio(s) ha(n) sido concedido(s)')
      except
        on E: EOracleError do
          case E.ErrorCode of
            00990: ShowMessage('Error: No posee el privilegio o no tiene privilegios para concederlo');
            01031: ShowMessage('Error: No tiene privilegios para conceder ese(esos) privilegio(s)');
          else
            ShowMessage(E.Message);
          end;
      end;
    end;
{    i := LstBxPermisosDisponibles.ItemIndex;
    RdGrpTipoObjetoClick(nil);
    LstBxPermisosDisponibles.ItemIndex := i;}
  end;
end;

procedure TFrmPermisos.LstBxPermisosDisponiblesClick(Sender: TObject);
begin
  SpdBtnGrant.Enabled := true;
  SpdBtnRevoke.Enabled := true;
end;

procedure TFrmPermisos.SpdBtnRevokeClick(Sender: TObject);
var
  Str, Temp : String;
  i         : Integer;
begin
  with OracleQuery.SQL do
  begin
    OracleQuery.Close;
    OracleQuery.DeleteVariables;
    Clear;

    Temp := '';
    for i := 0 to LstBxPermisosDisponibles.Items.Count -1 do
      if LstBxPermisosDisponibles.Selected[i] then
        Temp := Temp + LstBxPermisosDisponibles.Items[i] + ', ';
    SetLength(Temp, Length(Temp) - 2);

    Str := 'REVOKE ' + Temp;
    if CmBxObjetos.Enabled then
      Str := Str + ' ON ' + CmBxObjetos.Items[CmBxObjetos.ItemIndex];

    Str := Str + ' FROM ' + CmBxUsuarios.Items[CmBxUsuarios.ItemIndex];
    Add(Str);

    if CmBxUsuarios.Items[CmBxUsuarios.ItemIndex] = '' then
      ShowMessage('Debe seleccionar un usuario')
    else if LstBxPermisosDisponibles.Items[LstBxPermisosDisponibles.ItemIndex] = '' then
      ShowMessage('Debe seleccionar un privilegio')
    else begin
      try
        OracleQuery.Execute;
        ShowMessage('El(los) privilegio(s) ha(n) sido concedido(s)')
      except
        on E: EOracleError do
        begin
          case E.ErrorCode of
            00990: ShowMessage('Error: No posee el privilegio o no tiene privilegios para concederlo');
            01031: ShowMessage('Error: No tiene privilegios para conceder ese(esos) privilegio(s)');
            01927: ShowMessage('Error: No se puede revocar un privilegio no concedido');
          else
            ShowMessage(E.Message);
          end;
        end;
      end;
    end;
{    i := LstBxPermisosDisponibles.ItemIndex;
    RdGrpTipoObjetoClick(nil);
    LstBxPermisosDisponibles.ItemIndex := i;}
  end;
end;

end.

// 558
